Binarytree
----------

Welcome to the documentation for **binarytree**!

**Binarytree** is Python library which lets you generate, visualize, inspect and
manipulate binary trees. Skip the tedious work of setting up test data, and dive
straight into practising algorithms! Heaps and BSTs (binary search trees) are also
supported.

Requirements
============

Python 3.6+

Installation
============

Install via pip_:

.. code-block:: bash

    pip install binarytree

For conda_ users:

.. code-block:: bash

    conda install binarytree -c conda-forge

.. _pip: https://pip.pypa.io
.. _conda: https://docs.conda.io

Contents
========

.. toctree::
    :maxdepth: 1

    overview
    specs
    exceptions
    graphviz
